<?PHP
/**
 * Mapping for certainty-expressing fields to certainty in events.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Mapping for certainty-expressing fields to certainty in events.
 */
final class MDConcCertainty implements MDImporterConcordanceListInterface {

    private const MAPPING = [

        // Uncertain

        'fraglich' => false,
        'nach' => false,
        'Umkreis von' => false,
        'möglicherweise von' => false,
        'alternative Zuschreibung' => false,
        'Art des' => false,
        'Atelier von' => false,
        'ehemals zugeschrieben' => false,
        'Stil des' => false,
        'Schule von' => false,
        'Schule des' => false,
        'traditionelle Zuschreibung' => false,
        'Werkstatt von' => false,
        'zugeschriebe' => false,
        'zugeschrieben' => false,
        'zugeschrieben an' => false,

        // Certain

        'sicher' => true,
        'Zusammenarbeit mit' => true,
        'überarbeitet von' => true,
        'Nachfolger von' => true,
        'by' => true,

    ];

    /**
     * Require a function for getting the concordance target.
     *
     * @param string $input Input string.
     *
     * @return boolean
     */
    public static function getConcordanceTarget(string $input):bool {

        if (!isset(self::MAPPING[$input])) {
            throw new MDImporterMissingConcordance("Unknown certainty identifier: " . $input);
        }

        return self::MAPPING[$input];

    }
}
