<?PHP
/**
 * Constains lists for grouping languages.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Provides lists for categorizing spelled out languages.
 */
final class MDConcLanguages implements MDImporterConcordanceListInterface {

    private const LANGUAGES_LIST = [
        # English
        'English' => 'en',
        'englisch' => 'en',
        'Englisch' => 'en',
        'Englisch\'' => 'en',
        'eng' => 'en',
        'EN' => 'en',
        'ENG' => 'en',
        'eng; ger' => 'en',
        'en-GB' => 'en',

        # German
        'Deutsch' => 'de',
        'deutsch' => 'de',
        'German' => 'de',
        'ger' => 'de',
        'deu' => 'de',
        'Buch' => 'de',
        'Deutsch, Latein' => 'de',
        'deutsch, französisch' => 'de',
        'deutsch, russisch' => 'de',
        'deutsch u. plattdeutsch' => 'de',
        'deutsch / englisch' => 'de',
        'deurtsch' => 'de',
        'lat; ger' => 'de',
        'ger; lat' => 'de',
        'ger; eng' => 'de',

        # Latin
        'lat' => 'la',

        # Russian
        'rus' => 'ru',

        # Hungarian
        'Hungarian' => 'hu',
        'Magyar' => 'hu',

        # Czech
        'Tschechisch' => 'cs',
        'tschechisch' => 'cs',
        'cz' => 'cs',

        # Plattdeutsch / Niederdeutsch
        'plattdeutsch' => 'nds',

        # Latin
        'Latein' => 'la',
        'Latein, Deutsch, Italenisch, Spanisch, Englisch' => 'la',

        # French
        'fra' => 'fr',
        'fre' => 'fr',
        'Französisch' => 'fr',
        'französisch' => 'fr',

        # Italian
        'ita' => 'it',
        'it-it' => 'it',
        'italienisch' => 'it',
        'Italienisch' => 'it',

    ];

    /**
     * Require a function for getting the concordance target.
     *
     * @param string $input Input string.
     *
     * @return string
     */
    public static function getConcordanceTarget(string $input):string {

        if (!isset(self::LANGUAGES_LIST[$input])) {
            throw new MDImporterMissingConcordance("Unknown language type: " . $input);
        }

        return self::LANGUAGES_LIST[$input];

    }
}
