<?PHP
/**
 * Constains lists for grouping licenses.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Provides lists for categorizing spelled out licenses.
 */
final class MDConcLicenses implements MDImporterConcordanceListInterface {

    private const LICENSES_LIST = [
        "CCO" => "CC0",
        "CC 0" => "CC0",
        "CC_0" => "CC0",
        "CC O" => "CC0",
        "CC0 1.0" => "CC0",
        "CC 0 1.0" => "CC0",
        "CC_0 1.0" => "CC0",
        "CC0 1.0 Universell" => "CC0",
        "CC0 1.0 Universell (CC0 1.0)" => "CC0",
        "kein Copyright / Public domain (CC0 1.0)" => "CC0",
        "http://creativecommons.org/publicdomain/zero/1.0" => "CC0",
        "http://creativecommons.org/publicdomain/zero/1.0/" => "CC0",
        "http://creativecommons.org/publicdomain/zero/1.0/deed.de" => "CC0",
        "https://creativecommons.org/publicdomain/zero/1.0" => "CC0",
        "https://creativecommons.org/publicdomain/zero/1.0/" => "CC0",
        "https://creativecommons.org/publicdomain/zero/1.0/deed.de" => "CC0",

        "CC_BY" => "CC BY",
        "CC-BY" => "CC BY",
        "CC.BY" => "CC BY",
        "CC BY 4.0" => "CC BY",
        "CC_BY 4.0" => "CC BY",
        "CC-BY 4.0" => "CC BY",
        "CC.BY 4.0" => "CC BY",
        "http://creativecommons.org/licenses/by/4.0" => "CC BY",
        "http://creativecommons.org/licenses/by/4.0/" => "CC BY",
        "http://creativecommons.org/licenses/by/4.0/de" => "CC BY",
        "http://creativecommons.org/licenses/by/4.0/deed.de" => "CC BY",
        "https://creativecommons.org/licenses/by/4.0" => "CC BY",
        "https://creativecommons.org/licenses/by/4.0/" => "CC BY",
        "https://creativecommons.org/licenses/by/4.0/de" => "CC BY",
        "https://creativecommons.org/licenses/by/4.0/deed.de" => "CC BY",
        "Namensnennung 4.0. International (CC BY 4.0)" => "CC BY",
        "Namensnennung 4.0 International - CC BY 4.0" => "CC BY",

        "CC BY SA"  => "CC BY-SA",
        "CC BY-SA-" => "CC BY-SA",
        "CC BY_SA"  => "CC BY-SA",
        "CC_BY_SA"  => "CC BY-SA",
        "CC-BY-SA"  => "CC BY-SA",
        "CC.BY-SA"  => "CC BY-SA",
        "CC BY-SA 4.0"  => "CC BY-SA",
        "CC BY SA 4.0"  => "CC BY-SA",
        "CC BY-SA 4.1"  => "CC BY-SA",
        "CC BY-SA 4.2" => "CC BY-SA",
        "CC BY-SA 4.3"  => "CC BY-SA",
        "CC BY-SA 4.4"  => "CC BY-SA",
        "CC BY-SA 4.5"  => "CC BY-SA",
        "CC BY-SA 4.6"  => "CC BY-SA",
        "CC BY-SA 4.7"  => "CC BY-SA",
        "CC BY-SA 4.8"  => "CC BY-SA",
        "CC BY-SA 4.9"  => "CC BY-SA",
        "http://creativecommons.org/licenses/by-sa/3.0/" => "CC BY-SA",
        "http://creativecommons.org/licenses/by-sa/3.0/de" => "CC BY-SA",
        "http://creativecommons.org/licenses/by-sa/3.0/de/" => "CC BY-SA",
        "http://creativecommons.org/licenses/by-sa/3.0/deed.de" => "CC BY-SA",
        "https://creativecommons.org/licenses/by-sa/3.0/" => "CC BY-SA",
        "https://creativecommons.org/licenses/by-sa/3.0/de" => "CC BY-SA",
        "https://creativecommons.org/licenses/by-sa/3.0/de/" => "CC BY-SA",
        "https://creativecommons.org/licenses/by-sa/3.0/deed.de" => "CC BY-SA",
        "http://creativecommons.org/licenses/by-sa/4.0/" => "CC BY-SA",
        "http://creativecommons.org/licenses/by-sa/4.0/de" => "CC BY-SA",
        "http://creativecommons.org/licenses/by-sa/4.0/de/" => "CC BY-SA",
        "http://creativecommons.org/licenses/by-sa/4.0/deed.de" => "CC BY-SA",
        "https://creativecommons.org/licenses/by-sa/4.0/" => "CC BY-SA",
        "https://creativecommons.org/licenses/by-sa/4.0/de" => "CC BY-SA",
        "https://creativecommons.org/licenses/by-sa/4.0/de/" => "CC BY-SA",
        "https://creativecommons.org/licenses/by-sa/4.0/deed.de" => "CC BY-SA",
        "Namensnennung - Weitergabe unter gleichen Bedingungen 4.0 International (CC BY-SA 4.0)"  => "CC BY-SA",
        "Namensnennung 4.0 International (CC BY 4.0)" => "CC BY-SA",

        "CC BY_NC"  => "CC BY-NC",
        "CC_BY_NC"  => "CC BY-NC",
        "CC-BY-NC"  => "CC BY-NC",
        "CC.BY-NC"  => "CC BY-NC",
        "http://creativecommons.org/licenses/by-nc/4.0/"  => "CC BY-NC",
        "https://creativecommons.org/licenses/by-nc/4.0/"  => "CC BY-NC",

        "CC BY_NC_SA" => "CC BY-NC-SA",
        "CC_BY_NC_SA" => "CC BY-NC-SA",
        "CC BY NC SA" => "CC BY-NC-SA",
        "CC-BY-NC-SA" => "CC BY-NC-SA",
        "CC.BY-NC-SA" => "CC BY-NC-SA",
        "CC BY-NC-SA 3.0" => "CC BY-NC-SA",
        "CC BY-NC-SA 3.0 AT" => "CC BY-NC-SA",
        "CC BY-NC-SA 4.0" => "CC BY-NC-SA",
        "http://creativecommons.org/licenses/by-nc-sa/3.0/" => "CC BY-NC-SA",
        "http://creativecommons.org/licenses/by-nc-sa/4.0/deed.de" => "CC BY-NC-SA",
        "http://creativecommons.org/licenses/by-nc-sa/4.0/" => "CC BY-NC-SA",
        "https://creativecommons.org/licenses/by-nc-sa/4.0/" => "CC BY-NC-SA",
        "Namensnennung - Nicht kommerziell - Weitergabe unter gleichen Bedingungen 4.0 International (CC BY-NC-SA 4.0)" => "CC BY-NC-SA",

        "CC BY_NC_ND" => "CC BY-NC-ND",
        "CC_BY_NC_ND" => "CC BY-NC-ND",
        "CC-BY-NC-ND" => "CC BY-NC-ND",
        "CC.BY-NC-ND" => "CC BY-NC-ND",
        "CC BY-NC-ND 4.0" => "CC BY-NC-ND",
        "http://creativecommons.org/licenses/by-nc-nd/4.0/" => "CC BY-NC-ND",
        "https://creativecommons.org/licenses/by-nc-nd/4.0/" => "CC BY-NC-ND",
        "http://creativecommons.org/licenses/by-nc-nd/3.0/de/" => "CC BY-NC-ND",
        "https://creativecommons.org/licenses/by-nc-nd/4.0/deed.de" => "CC BY-NC-ND",
        "https://creativecommons.org/licenses/by-nc-nd/3.0/de/" => "CC BY-NC-ND",

        "https://www.deutsche-digitale-bibliothek.de/content/lizenzen/rv-fz" => "RR-F",
        "https://www.deutsche-digitale-bibliothek.de/content/lizenzen/rv-fz/" => "RR-F",
        "https//www.deutsche-digitale-bibliothek.de/content/lizenzen/rv-fz" => "RR-F",
        "http://www.deutsche-digitale-bibliothek.de/lizenzen/rv-fz/" => "RR-F",
        "https://www.deutsche-digitale-bibliothek.de/content/lizenzen/rv-ez" => "RR-F",
        "https://www.deutsche-digitale-bibliothek.de/content/lizenzen/rv-ez/" => "RR-F",
        "https//www.deutsche-digitale-bibliothek.de/content/lizenzen/rv-ez" => "RR-F",
        "http://www.deutsche-digitale-bibliothek.de/lizenzen/rv-ez/" => "RR-F",
        "http://www.europeana.eu/rights/rr-f/" => "RR-F",
        "https://www.europeana.eu/rights/rr-f/" => "RR-F",
        "Rechte vorbehalten - Freier Zugang" => "RR-F",
        "Rechte vorbehalten – Freier Zugang" => "RR-F",
        "http://rightsstatements.org/vocab/InC/1.0/" => "RR-F",
        "http://rightsstatements.org/page/InC/1.0/" => "RR-F",
        "https://rightsstatements.org/page/InC/1.0/" => "RR-F",
        "Alle Rechte vorbehalten" => "RR-F",
        "Alle Rechte vorbehalten." => "RR-F",
        "Alle Rechte vorbehalten - Urhebererechtlich geschütztes Werk" => "RR-F",
        "IN COPYRIGHT" => "RR-P",
        "Rechtsstatus unbekannt" => "RR-P",
        "none" => "RR-F",

        "http://www.europeana.eu/rights/rr-r/" => "RR-R",
        "https://www.europeana.eu/rights/rr-r/" => "RR-R",

        'PDM' => 'Public Domain Mark',
        'Public Domain Mark 1.0' => 'Public Domain Mark',
        'PDM 1.0' => 'Public Domain Mark',
        'https://creativecommons.org/public-domain/pdm/' => 'Public Domain Mark',
        'https://creativecommons.org/publicdomain/mark/1.0' => 'Public Domain Mark',
        'https://creativecommons.org/publicdomain/mark/1.0/' => 'Public Domain Mark',
        'https://creativecommons.org/publicdomain/mark/1.0/deed.de' => 'Public Domain Mark',
        'https://creativecommons.org/publicdomain/mark/1.0/deed.de/' => 'Public Domain Mark',
        'Public Domain Mark 1.0 - Weltweit frei von bekannten urheberrechtlichen Einschränkungen' => 'Public Domain Mark',

    ];

    /**
     * Require a function for getting the concordance target.
     *
     * @param string $input Input string.
     *
     * @return string
     */
    public static function getConcordanceTarget(string $input):string {

        if (!isset(self::LICENSES_LIST[$input])) {
            throw new MDImporterMissingConcordance("Unknown licence type: " . $input);
        }

        return self::LICENSES_LIST[$input];

    }
}
