<?PHP
/**
 * Constains lists for grouping measurement types.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Constains lists for grouping measurement types.
 */
final class MDConcMeasurementTypes implements MDImporterConcordanceListInterface {
    /**
     * Require a function for getting the concordance target.
     *
     * @param string $input Input string.
     *
     * @return MDMeasurementType|false
     */
    public static function getConcordanceTarget(string $input):MDMeasurementType|false {

        return match($input) {

            // Just list entries
            "Allgemein",
            "Passepartout",
            "Passepartout Standardformat",
            "Objektmaß",
            "Objektmass",
            "Außenmaß",
            "Außenmaß (Kiste)",
            "Bildmaß",
            "Bildmass",
            "Bildmaß (HxB)",
            "Auflagekarton (Höhe x Breite)",
            "Passepartout Standardformat (Höhe x Breite)",
            "Blattmaß",
            "Blattmass",
            "m",
            "cm",
            "mm",
            "dm",
            "Spieldauer (h___m___s)",
            "Geschwindigkeit (Schallplatte)",
            "Geschwindigkeit (Band)",
            "Transportmaß (Breite x Höhe x Tiefe)",
            "Transportmaß (Breite x Höhe x Tiefe)Transportmaß (Breite x Höhe x Tiefe)",
            "Öffnung (Durchmesser)",
            "Kartonformat (Höhe x Breite)",
            "Negativformat (Breite x Lange)",
            "Passepartout (Höhe x Breite)",
            "Montage (Breite x Länge)",
            "Verpackungsmaß (Breite x Höhe x Tiefe)Verpackungsmaß (Breite x Höhe x Tiefe)",
            "Maße Transport (Höhe x Tiefe x Breite)",
            "Volumen",
            "Hohlmaß",
            "Buchformat",
            "Hohlmass",
            "Kaliber",
            "Zeit",
            "Maßstab",
            "Original",
            "size",
            "base",
            "target",
            "Modell",
            "",
            "Plattengröße (Höhe x Breite)",
            "Sockel (Höhe x Tiefe x Breite)",
            "Sockel (Höhe x Tiefe x                                    Breite)",
            "Außenmaß (Höhe x Tiefe x Breite)",
            "Fläche",
            "Tafelmaß",
            "Tafelmass",
            "Radius",
            "Bemalte Fläche",
            "Bemalte Bildfläche",
            "Sockel",
            "Höhe x                                    Breite",
            "Höhe x                                    Durchmesser",
            "Rahmenmaß (Höhe x
                                    Breite)",
            "Höhe x Breite x                                    Tiefe",
            "Höhe x Breite x Tiefe",
            "Rahmenmaß",
            "Rahmenmaß (Höhe x Breite)",
            "Rahmenmaß (Höhe x                                    Breite)",
            "Rahmenmass",
            "Rahmenmass (Höhe x Breite)",
            "Rahmenaußenmaß (Höhe x Breite)",
            "Rahmenaußenmaß (Länge x Durchmesser)",
            "Höhe x Breite x Stärke",
            "Rahmenaußenmaß",
            "Rahmenaußenmass",
            "Kartonformat",
            "Kartonformat (Foto)",
            "Auflagekarton",
            "Bildformat (Foto)",
            "Tafelmaß (Höhe x Breite)",
            "Bemalte Bildfläche (Höhe x Breite)",
            "Plattengröße (Foto)",
            "Andere Maße",
            "Format",
            "Stichhöhe",
            "Maße Transport",
            "Länge x Breite x Höhe",
            "Länge x Breite x                                    Tiefe",
            "Länge x                                    Breite",
            "Maße Transport (Höhe x Tiefe x                                    Breite)",
            "Blattmaß (Höhe x Breite)",
            "Objektmaß (Höhe x Tiefe x Breite)",
            "Objektmaß (Höhe x Tiefe x                                    Breite)",
            "Teil 1",
            "Teil 2",
            "Teil 3",
            "Teil 4",
            "Teil 5",
            "Teil 6",
            "Teil 7",
            "Teil 8",
            "Kistenmaß (Länge x Breite x Höhe)",
            "Umfang",
            "Umfang",
            "Kaliber",
            "Ölfarbe",
            "2 kg-Gewicht",
            "2. Hälfte 18. Jh.",
            "14.1x9.2",
            "14x9.1",
            "cm",
            "13.9x8.6",
            "Grundfläche",
            "Länge x Breite",
            "Bildmaß (Höhe x Breite)",
            "Bildformat (Höhe x Breite)",
            "Glasmaß (Höhe x Breite)",
            "Länge x Breite x Tiefe",
            "Höhe x Durchmesser",
            "Länge x Durchmesser",
            "Breite x Höhe",
            "Breite x Höhe x Tiefe",
            "Breite x                                    Höhe",
            "Breite x Tiefe",
            "Höhe x Breite",
            "Höhe x Breite (aufgeschlagen)",
            "Höhe x Breite x Tiefe",
            "Durchmesser x Tiefe",
            "Durchmesser x                                    Tiefe",
            "Gesamtmaß (Höhe x Breite x Tiefe)",
            "Form",
            "Andere",
            "Prefix",
            "Kartierung",
            "Masstab",
            "Sitzhöhe",
            "Auflagekarton Standardformat",
            "Bruttomass",
            "Kistenmass",
            "Kistenmass (Höhe)",
            "Lichtmass",
            "Kistenmass (Tiefe)",
            "Kistenmass (Breite)",
            "Suffix",
            "HxBxT",
            "Objektmaß (HxB)",
            "CC",
            "Eisen",
            "mm",
            "Größe",
            "CdV",
            "Stichhöhe (Höhe x Breite)" => false,

            "Höhe",
            "(Höhe)",
            " (Höhe)",
            "Höhe (gesamt)",
            "Höhe (Objekt)",
            "Höhe (Etui)",
            "Höhe (netto)",
            "Höhe (ausgeklappt)",
            "Höhe größtes Stück",
            "height",
            "height (overall)",
            "Lichtmass (Höhe)",
            "Bruttomass (Höhe)",
            "Kartierung (Höhe)",
            "Masstab (Höhe)",
            "Sitzhöhe (Höhe)",
            "Höhe (Platte)",
            "Außenmaß (Höhe)",
            "Objektmaß (Höhe)",
            "Objektmass (Höhe)",
            'Höhe (Holzstock)',
            'Höhe (Untersatzbogen)',
            'Höhe (Buchblock)',
            'Höhe (Buchblock ohne Einband)',
            'Höhe (Buchblock mit Einband)',
            'Höhe (Stein)',
            'Höhe (Schuber)',
            'Höhe (Karton)',
            'Höhe (Einleger)',
            'Höhe (Einleger 1)',
            'Höhe (Einleger 2)',
            'Höhe (Einleger 3)',
            'Höhe (EInleger 3)',
            'Höhe (Einleger 4)',
            'Höhe (Einleger 5)',
            'Höhe (Einleger 6)',
            'Höhe (Einleger 7)',
            'Höhe (Einleger 4-6)',
            'Höhe (Einleger 8)',
            'Höhe (Einleger 9)',
            'Höhe (Einleger 10)',
            'Höhe (Einleger 11)',
            'Höhe (Einleger 12)',
            'Höhe (Einleger 13)',
            'Höhe (Einleger 14)',
            'Höhe (Einleger 15)',
            'Höhe (Einleger 16)',
            'Höhe (Einleger 17)',
            'Höhe (Einleger 18)',
            'Höhe (Einleger 19)',
            'Höhe (Einleger 20)',
            'Höhe (Einleger 21)',
            'Höhe (Einleger 22)',
            'Höhe (Einleger 23)',
            'Höhe (Einleger 24)',
            "Reliefhöhe" => MDMeasurementType::height,

            "Länge",
            "Länge OT",
            "Länge H",
            "Länge (ausgeklappt)",
            "length",
            "(Länge)",
            " (Länge)",
            "Länge/Tiefe",
            "Länge / Tiefe",
            "Lichtmass (Länge)",
            "Lichtmass (Tiefe)",
            "Tiefe",
            "Tiefe (mit Hinterrad in Fahrtrichtung)",
            "Tiefe (zusammengeklappt)",
            "Tiefe (Etui)",
            "Tiefe (mit eingeklapptem Hinterrad)",
            "Tiefe/Länge",
            "Tiefe min",
            "Tiefe max",
            "Tiefe/Länge (Objekt)",
            "Außenmaß (Tiefe)",
            "Teife",
            "length",
            "Bruttomass (Länge)",
            "Bruttomass (Tiefe)",
            "Kartierung (Länge)",
            "Kartierung (Tiefe)",
            "Masstab (Länge)",
            "Masstab (Tiefe)",
            "Sitzhöhe (Länge)",
            "Sitzhöhe (Tiefe)",
            "Länge (Platte)",
            "Tiefe (Platte)",
            "Objektmaß (Länge)",
            "Objektmaß (Tiefe)",
            "Objektmass (Länge)",
            "Objektmass (Tiefe)",
            'Länge (Holzstock)',
            'Tiefe (Holzstock)',
            'Länge (Untersatzbogen)',
            'Tiefe (Untersatzbogen)',
            'Länge (Buchblock)',
            'Tiefe (Buchblock)',
            'Länge (Buchblock ohne Einband)',
            'Tiefe (Buchblock ohne Einband)',
            'Länge (Buchblock mit Einband)',
            'Tiefe (Buchblock mit Einband)',
            'Länge (Stein)',
            'Tiefe (Stein)',
            'Länge (Schuber)',
            'Tiefe (Schuber)',
            'Länge (Karton)',
            'Tiefe (Karton)',
            'Länge (Einleger)',
            'Tiefe (Einleger)',
            'Länge (Einleger 1)',
            'Tiefe (Einleger 1)',
            'Länge (Einleger 2)',
            'Tiefe (Einleger 2)',
            'Länge (Einleger 3)',
            'Tiefe (Einleger 3)',
            "depth",
            "Dicke" => MDMeasurementType::length,

            "Breite",
            "Breite OT",
            "Breite H",
            "Breite (ausgeklappt)",
            "Breite (Etui)",
            "Breite (netto)",
            "Breite (aufgeschlagen)",
            "Breite größtes Stück",
            "Breite (gesamt)",
            "Breite (Objekt)",
            "Breite (Platte)",
            "(Breite)",
            "Lichtmass (Breite)",
            " (Breite)",
            "width",
            "width (overall)",
            "Außenmaß (Breite)",
            "Bruttomass (Breite)",
            "Objektmaß (Breite)",
            "Objektmass (Breite)",
            "Kartierung (Breite)",
            "Masstab (Breite)",
            "Sitzhöhe (Breite)",
            'Breite (Holzstock)',
            'Breite (Untersatzbogen)',
            'Breite (Buchblock)',
            'Breite (Buchblock ohne Einband)',
            'Breite (Buchblock mit Einband)',
            'Breite (Buchblock mit Einabnd)',
            'Breite (Stein)',
            'Breite (Schuber)',
            'Breite (Karton)',
            'Breite (Einleger)',
            'Breite (Einleger 1)',
            'Breite (Einleger 2)',
            'Breite (Einleger 3)',
            'Breite (Einleger 4)',
            'Breite (EInleger 4)',
            'Breite (Einleger 5)',
            'Breite (Einleger 6)',
            'Breite (EInleger 6)',
            'Breite (Einleger 7)',
            'Breite (EInleger 7)',
            'Breite (Einleger 8)',
            'Breite (Einleger 9)',
            'Breite (Einleger 10)',
            'Breite (Einleger 11)',
            'Breite (Einleger 12)',
            'Breite (Einleger 13)',
            'Breite (Einleger 14)',
            'Breite (Einleger 15)',
            'Breite (Einleger 16)',
            'Breite (EInleger 16)',
            'Breite (Einleger 17)',
            'Breite (Einleger 18)',
            'Breite (Einleger 19)',
            'Breite (Einleger 20)',
            'Breite (Einleger 21)',
            "Stärke",
            "Schenkelbreite (Breite)" => MDMeasurementType::width,

            "Durchmesser",
            "Durchm.",
            "Durchmesser (mit Dicke)",
            "Durchmesser (Boden)",
            "Mündung (Durchmesser)",
            "Rahmenaußenmaß Durchmesser",
            "diameter",
            "Außenmaß (Durchmesser)",
            "Durchmesser in Richtung Bohrung",
            "Durchmesser quer zur Bohrung",
            "Durchmesser Fuß",
            "Durchmesser Oben",
            "Durchmesser oben",
            "Durchmesser unten",
            "Durchmesser (Höhe)",
            "Durchmesser (Breite)",
            "Durchmesser (Tiefe)",
            "Durchmesser (Länge)",
            "Objektmaß (Durchmesser)",
            "Objektmass (Durchmesser)",
            "d",
            "Ø" => MDMeasurementType::diameter,

            "width of wall",
            "Laufwandung",
            "Stärke",
            "Wandstärke (Durchmesser)" => MDMeasurementType::wall,

            "Length of socle",
            "Tiefe/Länge (Sockel)",
            "Länge (Sockel)" => MDMeasurementType::length_socle,

            "Height of socle",
            "Höhe (Sockel)" => MDMeasurementType::height_socle,

            "Width of socle",
            "Breite (Sockel)" => MDMeasurementType::height_socle,

            "Höhe (Blatt)",
            "Blattmaß (Höhe)",
            "Blattmass (Höhe)" => MDMeasurementType::height_sheet_size,

            "Breite (Blatt)",
            "Blattmaß (Breite)",
            "Blattmass (Breite)" => MDMeasurementType::width_sheet_size,

            "Blattmaß (Länge)",
            "Blattmaß (Tiefe)",
            "Blattmass (Länge)",
            "Tiefe/Länge (Blatt)",
            "Blattmass (Tiefe)" => MDMeasurementType::length_sheet_size,

            "Höhe (Bild)",
            "Höhe (Darstellung)",
            "Bildmaß (Höhe)",
            "Bildmass (Höhe)" => MDMeasurementType::height_image_size,

            "Breite (Bild)",
            "Breite (Darstellung)",
            "Bildmaß (Breite)",
            "Bildmass (Breite)" => MDMeasurementType::width_image_size,

            "Bildmaß (Länge)",
            "Bildmaß (Tiefe)",
            "Tiefe (Darstellung)",
            "LängLängee (Darstellung)",
            "Bildmass (Länge)",
            "Bildmass (Tiefe)" => MDMeasurementType::length_image_size,

            "Höhe (Rahmen)",
            "Rahmenmaß (Höhe)",
            "Rahmenmass (Höhe)" => MDMeasurementType::height_frame,

            "Breite (Rahmen)",
            "Rahmenmaß (Breite)",
            "Rahmenmass (Breite)" => MDMeasurementType::width_frame,

            "Tiefe (Rahmen)",
            "Rahmenmaß (Länge)",
            "Rahmenmaß (Tiefe)",
            "Rahmenmass (Länge)",
            "Rahmenmass (Tiefe)" => MDMeasurementType::length_frame,

            "Höhe min.",
            'Höhe min (Blatt)',
            'Höhe min (Einleger)',
            'Höhe min (Einleger 1)',
            'Höhe min (Einleger 2)',
            'Höhe min (Einleger 3)',
            'Höhe min (Einleger 4)',
            'Höhe min (Einleger 5)',
            'Höhe min (Schuber)' => MDMeasurementType::height_min,
            "Höhe max.",
            'Höhe max (Blatt)',
            'Höhe max (Einleger)',
            'Höhe max (Einleger 1)',
            'Höhe max (Einleger 2)',
            'Höhe max (Einleger 3)',
            'Höhe max (Einleger 4)',
            'Höhe max (Einleger 5)',
            'Höhe max (Schuber)' => MDMeasurementType::height_max,

            "Länge min.",
            "Tiefe min.",
            'Länge min (Blatt)',
            'Tiefe min (Blatt)' => MDMeasurementType::length_min,
            "Länge max.",
            "Tiefe max.",
            "Länge max (Blatt)",
            "Tiefe max (Blatt)" => MDMeasurementType::length_max,

            "Breite min.",
            'Breite min (Blatt)',
            'Breite min (Einleger)',
            'Breite min (Schuber)' => MDMeasurementType::width_min,
            "Breite max.",
            'Breite max (Blatt)',
            'Breite max (Einleger)',
            'Breite max (Einleger 1)',
            'Breite max (Einleger 2)',
            'Breite max (Einleger 3)',
            'Breite max (Einleger 4)',
            'Breite max (Einleger 5)',
            'Breite max (Einleger 4-6)',
            'Breite max (Schuber)' => MDMeasurementType::width_max,

            "Diameter min." => MDMeasurementType::diameter_min,
            "Diameter max." => MDMeasurementType::diameter_max,

            "Durchmesser (Rahmen)" => MDMeasurementType::diameter_frame,

            "weight",
            "Gewicht (Höhe)",
            "Gewicht (Breite)",
            "Gewicht (Tiefe)",
            "Gewicht (Länge)",
            "Gewicht" => MDMeasurementType::weight,

            "number of pages",
            "Seitenzahl",
            "Seitenzahl (Höhe)",
            "Seitenzahl (Breite)",
            "Seitenzahl (Tiefe)",
            "Paginierung" => MDMeasurementType::number_of_parts,

            "Die Axis",
            "die-axis",
            "orientation",
            "Stempelstellung" => MDMeasurementType::die_axis,

            default => throw new MDImporterMissingConcordance("Unmapped specific measurement type: " . $input),

        };

    }
}
