<?PHP
/**
 * Constains lists for categorizing source types.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Provides a list for finding the source type for an input.
 */
final class MDConcSourceTypes implements MDImporterConcordanceListInterface {

    private const SOURCE_TYPES = [

        // Article
        "document]article" => "article",

        // Book / default
        "" => "book",
        "buch" => "book",
        "literatur" => "book",
        "document]book" => "book",

        // Misc
        "document]avm" => "misc",

    ];

    /**
     * Require a function for getting the concordance target.
     *
     * @param string $input Input string.
     *
     * @return string
     */
    public static function getConcordanceTarget(string $input):string {

        if (isset(self::SOURCE_TYPES[$input])) {
            return self::SOURCE_TYPES[$input];
        }
        if (isset(self::SOURCE_TYPES[strtolower($input)])) {
            return self::SOURCE_TYPES[strtolower($input)];
        }

        throw new MDImporterMissingConcordance("Unknown source type: " . $input);

    }
}
